from setuptools import setup

setup(
     name='qwackchat',    # This is the name of your PyPI-package.
     version='0.1.8.1',                          # Update the version number for new releases
     scripts=['qwackchat','sqwackchat','gui.py']                  # The name of your scipt, and also the command you'll be using for calling it
)
